==> fetch.php?media=snfit-2.2.2.tar.gz: snfit-2.2.2/src/model2fit.h <==
#ifndef MODEL2FIT__H
#define MODEL2FIT__H


#include <string>
#include <map>

#include "param.h"
#include "sampledfunction.h"
#include "measureddata.h"


/** virtual class of model
 * This model is loaded only with a file containing  the data.
 *
 * It creates by itself the needed parameters  params and z with CreateParams()
 * and knowns how to handle them in the function Flux, from the MeasuredPassBand
 * a model is identified by its name ModelName()
*/
class Model2Fit {

 protected:

  double BlueCutoff;
  double RedCutoff;


public:
  // this is a vector<LcParam *>
  FitParams params;
  
  Model2Fit() {}
  virtual ~Model2Fit() {}
  
  //! cool stuff
  void FixParameter(const string &paramname,double value,double error=0);
  
  //! cool stuff
  void SetParameterRange(const string &paramname,const double &min_value,const double &max_value);
  
  
  void SetParameterValue(const string &paramname,double value);
  
  //! flux to be compared to the data
  virtual double Flux(const Filter* filter,
		      const double observerday) const = 0;
  

//! flux to be compared to the data
  virtual double ModelRelativeError(const Filter* filter,
				    const double observerday, bool with_scaling = false);
  
#ifndef NEW_ERRORS
   
  //! flux to be compared to the data
  virtual double ModelKError(const Filter* filter);
  
#else
  virtual double ModelRelativeCovariance(const Filter* filter,
					 const double observerday1,
					 const double observerday2);
#endif
  
  //! flux to be compared to the data
  virtual double SpectrumFlux(const double observerlambda,  
			      const double observerday) const;  
  
  
  virtual double SpectrumModelError(const double observerlambda,  
				    const double observerday, bool with_scaling = false);  
  
  virtual double GalaxySpectrumFlux(const double observerlambda, bool only_galaxy=false); 
  virtual bool CanFitGalaxySpectrum() const {return false;};

  //! class name
  virtual string ModelName() const { return "Model2Fit"; }

  //! init parameters before starting a minuit fit
  virtual void InitParams(const MeasuredData* data) = 0;
  
  //! init parameters before starting a minuit fit
  virtual vector<LcParam*> InitCalibrationParams(const MeasuredSpectrum *spec, int n_recalibration_params = 1);
  
  //! needed for the fit, minuit parameters -> model parameters
  void SetParams(const double *p, const int nval);
  
  //! update internal stuff with modification of parameters
  virtual void Update() {}; 
  
  //! read parameters from a file
  virtual void ReadParams(const string& filename);
    
  //! check whether the wavelength range defined by the filter is included in the spectral range of the model
  virtual bool CanComputeFluxFor(const Filter& observerfilter, bool quiet=false) const = 0;
  
  //! allow the model to select its favourite sub-dataset, will remove some elements of  MeasuredData
  //virtual void KeepOnlyNBands(int n,MeasuredData* data) = 0;

  // a few tools for error propagation
  //! for varying parameters
  virtual bool GetParamsCovMatrix(Mat &Cov) const;


  
  


  
  //! Gradient and value of Rf mag w.r.t varying parameters
  virtual bool GetRestFrameMagParamGrad(const Filter& filter, double phase,
					 Vect &Grad,
					 double &Mag,
					const string &magsys);

  //! for several mags at a time, with covariances.
  virtual bool GetRestFrameMagsAtPhase(const vector<Filter> &filters, double phase, 
				       FitParams &Mags,
				       const string &magsys);
   
  //! filter is restframe , i.e. for B, filter.Mean()~=4400.
  virtual double GetRestFrameMagAtPhase(const Filter& filter, double phase, 
					const string &magsys);

  //! MagAndP contains the original parameters + the Rf mag and the covariances
  bool GetRestFrameMagAndCov(const Filter &filter, double phase, 
			     FitParams &MagAndP,
			     const string &magsys);

  
  //! Gradient and value of Rf mag w.r.t varying parameters
  virtual bool GetMagParamGrad(const Filter& filter, double phase,
			       Vect &Grad,
			       double &Mag,
			       const string &magsys);
  
  //! 
  virtual double GetMagAtPhase(const Filter& filter, double phase, 
			       const string &magsys);
  

  bool GetMagsAtPhase(const vector<Filter> &filters, double phase, 
		      FitParams &Mags,
		      const string &magsys);

  virtual double GetPhase(double date) const = 0;

  virtual void GetWavelengthRange(double& wmin, double& wmax) const {
    wmin = BlueCutoff;
    wmax = RedCutoff;
  } 
  virtual void SetWavelengthRange(const double& blue, const double& red) {
    BlueCutoff = blue;
    RedCutoff  = red;
  }
  virtual double SpectrumCalibration(const double observerlambda, 
				     const MeasuredSpectrum& spectrum);
};


  // const string& ModelFileName() const {return fModelFileName;}
  //double DayWithMaxFlux(const MeasuredPointList &List);
  

Model2Fit *NewModel2Fit(const string &FileName);


#endif /* MODEL2FIT__H */

==> fetch.php?media=snfit-2.4.1.tar.gz: snfit-2.4.2/src/model2fit.h <==
#ifndef MODEL2FIT__H
#define MODEL2FIT__H


#include <string>
#include <map>

#include "param.h"
#include "sampledfunction.h"
#include "measureddata.h"


/** virtual class of model
 * This model is loaded only with a file containing  the data.
 *
 * It creates by itself the needed parameters  params and z with CreateParams()
 * and knowns how to handle them in the function Flux, from the MeasuredPassBand
 * a model is identified by its name ModelName()
*/
class Model2Fit {

 protected:

  double BlueCutoff;
  double RedCutoff;


public:
  // this is a std::vector<LcParam *>
  FitParams params;
  
  Model2Fit() {}
  virtual ~Model2Fit() {}
  
  //! cool stuff
  bool FixParameter(const std::string &paramname,double value,double error=0);
  
  //! cool stuff
  bool SetParameterRange(const std::string &paramname,const double &min_value,const double &max_value);
  
  
  bool SetParameterValue(const std::string &paramname,double value);
  
  //! flux to be compared to the data
  virtual double Flux(const Filter* filter,
		      const double observerday) const = 0;
  

//! flux to be compared to the data
  virtual double ModelRelativeError(const Filter* filter,
				    const double observerday, bool with_scaling = false);
  
#ifndef NEW_ERRORS
   
  //! flux to be compared to the data
  virtual double ModelKError(const Filter* filter);
  
#else
  virtual double ModelRelativeCovariance(const Filter* filter,
					 const double observerday1,
					 const double observerday2);
#endif
  
  //! flux to be compared to the data
  virtual double SpectrumFlux(const double observerlambda,  
			      const double observerday) const;  
  
  
  virtual double SpectrumModelError(const double observerlambda,  
				    const double observerday, bool with_scaling = false);  
  
  virtual double GalaxySpectrumFlux(const double observerlambda, bool only_galaxy=false); 
  virtual bool CanFitGalaxySpectrum() const {return false;};

  //! class name
  virtual std::string ModelName() const { return "Model2Fit"; }

  //! init parameters before starting a minuit fit
  virtual void InitParams(const MeasuredData* data) = 0;
  
  //! init parameters before starting a minuit fit
  virtual std::vector<LcParam*> InitCalibrationParams(const MeasuredSpectrum *spec, int n_recalibration_params = 1);
  
  //! needed for the fit, minuit parameters -> model parameters
  void SetParams(const double *p, const int nval);
  
  //! update internal stuff with modification of parameters
  virtual void Update() {}; 
  
  //! read parameters from a file
  virtual void ReadParams(const std::string& filename);
    
  //! check whether the wavelength range defined by the filter is included in the spectral range of the model
  virtual bool CanComputeFluxFor(const Filter& observerfilter, bool quiet=false) const = 0;
  
  //! allow the model to select its favourite sub-dataset, will remove some elements of  MeasuredData
  //virtual void KeepOnlyNBands(int n,MeasuredData* data) = 0;

  // a few tools for error propagation
  //! for varying parameters
  virtual bool GetParamsCovMatrix(Mat &Cov) const;


  
  


  
  //! Gradient and value of Rf mag w.r.t varying parameters
  virtual bool GetRestFrameMagParamGrad(const Filter& filter, double phase,
					 Vect &Grad,
					 double &Mag,
					const std::string &magsys);

  //! for several mags at a time, with covariances.
  virtual bool GetRestFrameMagsAtPhase(const std::vector<Filter> &filters, double phase, 
				       FitParams &Mags,
				       const std::string &magsys);
   
  //! filter is restframe , i.e. for B, filter.Mean()~=4400.
  virtual double GetRestFrameMagAtPhase(const Filter& filter, double phase, 
					const std::string &magsys);

  //! MagAndP contains the original parameters + the Rf mag and the covariances
  bool GetRestFrameMagAndCov(const Filter &filter, double phase, 
			     FitParams &MagAndP,
			     const std::string &magsys);

  
  //! Gradient and value of Rf mag w.r.t varying parameters
  virtual bool GetMagParamGrad(const Filter& filter, double phase,
			       Vect &Grad,
			       double &Mag,
			       const std::string &magsys);
  
  //! 
  virtual double GetMagAtPhase(const Filter& filter, double phase, 
			       const std::string &magsys);
  

  bool GetMagsAtPhase(const std::vector<Filter> &filters, double phase, 
		      FitParams &Mags,
		      const std::string &magsys);

  virtual double GetPhase(double date) const = 0;

  virtual void GetWavelengthRange(double& wmin, double& wmax) const {
    wmin = BlueCutoff;
    wmax = RedCutoff;
  } 
  virtual void SetWavelengthRange(const double& blue, const double& red) {
    BlueCutoff = blue;
    RedCutoff  = red;
  }
  virtual double SpectrumCalibration(const double observerlambda, 
				     const MeasuredSpectrum& spectrum);

  /* SZF */
  /* Calculates phase of maximum and maximum flux for observerfilter. Calculates the dm15 in the same band*/
  GlobalVal CalcDM15(const Filter& observerfilter);

};


  // const std::string& ModelFileName() const {return fModelFileName;}
  //double DayWithMaxFlux(const MeasuredPointList &List);
  

Model2Fit *NewModel2Fit(const std::string &FileName);

Model2Fit *SnModel2Fit(const std::string &ModelName, const bool Warn=true);


#endif /* MODEL2FIT__H */
